.. image:: https://img.shields.io/readthedocs/acquantum_qiskit.svg?style=for-the-badge
    :target: https://acquantum_qiskit.readthedocs.io/en/latest/?badge=latest
    :alt: Read the Docs

.. image:: https://img.shields.io/travis/com/carstenblank/acquantum_qiskit.svg?style=for-the-badge
    :target: https://travis-ci.com/carstenblank/acquantum_qiskit
    :alt: Travis Build

.. image:: https://img.shields.io/codacy/grade/83e6c1a12f7942998cbbeb3d34f08964.svg?style=for-the-badge
    :target: https://www.codacy.com?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=sebboer/acquantum_qiskit&amp;utm_campaign=Badge_Grade
    :alt: Codacy